EMG
-------

Main
^^^^^^^^^^^^^^^^
*emg_process()*
"""""""""""""""""
.. autofunction:: neurokit2.emg.emg_process

*emg_analyze()*
""""""""""""""""
.. autofunction:: neurokit2.emg.emg_analyze

*emg_simulate()*
"""""""""""""""""
.. autofunction:: neurokit2.emg.emg_simulate

*emg_plot()*
""""""""""""""""""""""
.. autofunction:: neurokit2.emg.emg_plot


Preprocessing
^^^^^^^^^^^^^^^^
*emg_clean()*
""""""""""""""
.. autofunction:: neurokit2.emg.emg_clean

*emg_amplitude()*
""""""""""""""""""
.. autofunction:: neurokit2.emg.emg_amplitude

*emg_activation()*
""""""""""""""""""""
.. autofunction:: neurokit2.emg.emg_activation


Analysis
^^^^^^^^^
*emg_eventrelated()*
""""""""""""""""""""""
.. autofunction:: neurokit2.emg.emg_eventrelated

*emg_intervalrelated()*
""""""""""""""""""""""""
.. autofunction:: neurokit2.emg.emg_intervalrelated



*Any function appearing below this point is not explicitly part of the documentation and should be added. Please open an issue if there is one.*

.. automodule:: neurokit2.emg
   :members:
   :exclude-members: emg_process, emg_analyze, emg_simulate, emg_plot, emg_clean, emg_amplitude, emg_activation, emg_eventrelated, emg_intervalrelated


